@@ -22,6 +22,9 @@ from pm4py.algo.discovery.correlation_mining.variants import classic
 from collections import Counter
 import numpy as np
 import pandas as pd
+from typing import Optional, Dict, Any, Union, Tuple
+from pm4py.objects.log.obj import EventLog, EventStream
+import pandas as pd
 
 
 class Parameters(Enum):
@@ -31,7 +34,7 @@ class Parameters(Enum):
     SAMPLE_SIZE = "sample_size"
 
 
-def apply(log, parameters=None):
+def apply(log: Union[EventLog, EventStream, pd.DataFrame], parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> Tuple[Dict[Tuple[str, str], int], Dict[Tuple[str, str], float]]:
     """
     Applies the correlation miner (splits the log in smaller chunks)
 
