@@ -44,7 +44,7 @@ VERSIONS = {Variants.IMd, Variants.IM, Variants.IMf, Variants.IM_CLEAN}
 
 DEFAULT_VARIANT_LOG = IM_CLEAN
 DEFAULT_VARIANT_VARIANTS = IM_CLEAN
-DEFAULT_VARIANT_DFG = IMd
+DEFAULT_VARIANT_DFG = IM_CLEAN
 
 
 def apply(log: Union[EventLog, EventStream, pd.DataFrame], parameters: Optional[Dict[Any, Any]] = None, variant=DEFAULT_VARIANT_LOG) -> Tuple[PetriNet, Marking, Marking]:
@@ -75,7 +75,7 @@ def apply(log: Union[EventLog, EventStream, pd.DataFrame], parameters: Optional[
     return exec_utils.get_variant(variant).apply(log, parameters=parameters)
 
 
-def apply_dfg(dfg: Dict[Tuple[str, str], int], parameters=None, variant=DEFAULT_VARIANT_DFG) -> Tuple[PetriNet, Marking, Marking]:
+def apply_dfg(dfg: Dict[Tuple[str, str], int], start_activities: Dict[str, int], end_activities: Dict[str, int], activities: Dict[str, int], parameters=None, variant=DEFAULT_VARIANT_DFG) -> Tuple[PetriNet, Marking, Marking]:
     """
     Apply the chosen IM algorithm to a DFG graph obtaining a Petri net along with an initial and final marking
 
@@ -100,7 +100,7 @@ def apply_dfg(dfg: Dict[Tuple[str, str], int], parameters=None, variant=DEFAULT_
     final_marking
         Final marking
     """
-    return exec_utils.get_variant(variant).apply_dfg(dfg, parameters=parameters)
+    return exec_utils.get_variant(variant).apply_dfg(dfg, start_activities=start_activities, end_activities=end_activities, activities=activities, parameters=parameters)
 
 
 def apply_tree(log: Union[EventLog, EventStream, pd.DataFrame], parameters: Optional[Dict[Any, Any]] = None, variant=DEFAULT_VARIANT_LOG) -> ProcessTree:
@@ -127,7 +127,7 @@ def apply_tree(log: Union[EventLog, EventStream, pd.DataFrame], parameters: Opti
     return exec_utils.get_variant(variant).apply_tree(log, parameters=parameters)
 
 
-def apply_tree_dfg(dfg: Dict[Tuple[str, str], int], parameters: Optional[Dict[Any, Any]] = None, variant=DEFAULT_VARIANT_DFG) -> ProcessTree:
+def apply_tree_dfg(dfg: Dict[Tuple[str, str], int], start_activities: Dict[str, int], end_activities: Dict[str, int], activities: Dict[str, int], parameters: Optional[Dict[Any, Any]] = None, variant=DEFAULT_VARIANT_DFG) -> ProcessTree:
     """
     Apply the chosen IM algorithm to a DFG graph obtaining a process tree
 
@@ -148,7 +148,7 @@ def apply_tree_dfg(dfg: Dict[Tuple[str, str], int], parameters: Optional[Dict[An
     tree
         Process tree
     """
-    return exec_utils.get_variant(variant).apply_tree_dfg(dfg, parameters=parameters)
+    return exec_utils.get_variant(variant).apply_tree_dfg(dfg, start_activities=start_activities, end_activities=end_activities, activities=activities, parameters=parameters)
 
 
 def apply_variants(variants: Dict[Union[str, List[str]], int], parameters: Optional[Dict[Any, Any]] = None, variant=DEFAULT_VARIANT_VARIANTS) -> Tuple[PetriNet, Marking, Marking]:
