@@ -18,6 +18,7 @@ from enum import Enum
 from typing import Any, Dict, Optional, Set, Union
 
 import pm4py
+from pm4py.objects.conversion.log import converter
 from pm4py.algo.discovery.minimum_self_distance import algorithm as msd_algo
 from pm4py.objects.log.obj import EventLog
 from pm4py.util import constants, exec_utils, xes_constants
@@ -51,7 +52,7 @@ def derive_msd_witnesses(log: EventLog, msd: Optional[Dict[Any, int]] = None,
     Dictionary mapping each activity to a set of witnesses.
 
     '''
-    log = pm4py.convert_to_event_log(log)
+    log = converter.apply(log, variant=converter.Variants.TO_EVENT_LOG, parameters=parameters)
     act_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters,
                                          xes_constants.DEFAULT_NAME_KEY)
     alphabet = pm4py.get_event_attribute_values(log, act_key)
