@@ -14,4 +14,9 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.enhancement import sna, roles, comparison, decision
+import warnings
+
+from pm4py.algo.enhancement import sna, roles, comparison, decision, organizational_mining, resource_profiles
+
+warnings.warn(
+    "pm4py.algo.enhancement is deprecated. please use pm4py.algo.decision_mining, pm4py.algo.comparison and pm4py.algo.organizational_mining instead")
