@@ -14,7 +14,8 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.evaluation import precision, replay_fitness, simplicity, generalization
+
+from pm4py.algo.evaluation import precision, replay_fitness, simplicity, generalization, algorithm
 import pkgutil
 
 if pkgutil.find_loader("pyemd"):
