@@ -14,4 +14,9 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.transformation.log_to_features import algorithm, variants, util
+from pm4py.algo.transformation.log_to_features import algorithm, variants
+
+import pkgutil
+
+if pkgutil.find_loader("sklearn"):
+    from pm4py.algo.transformation.log_to_features import util
