@@ -39,10 +39,10 @@ def filter_(func, log):
     '''
     if isinstance(log, log_inst.EventLog):
         return log_inst.EventLog(list(filter(func, log)), attributes=log.attributes, classifiers=log.classifiers,
-                                 omni_present=log.omni_present, extensions=log.extensions)
+                                 omni_present=log.omni_present, extensions=log.extensions, properties=log.properties)
     elif isinstance(log, log_inst.EventStream):
         return log_inst.EventStream(list(filter(func, log)), attributes=log.attributes, classifiers=log.classifiers,
-                                    omni_present=log.omni_present, extensions=log.extensions)
+                                    omni_present=log.omni_present, extensions=log.extensions, properties=log.properties)
     else:
         warnings.warn('input log object not of appropriate type, filter() not applied')
         return log
@@ -66,10 +66,10 @@ def map_(func, log):
         '''
     if isinstance(log, log_inst.EventLog):
         return log_inst.EventLog(list(map(func, log)), attributes=log.attributes, classifiers=log.classifiers,
-                                 omni_present=log.omni_present, extensions=log.extensions)
+                                 omni_present=log.omni_present, extensions=log.extensions, properties=log.properties)
     elif isinstance(log, log_inst.EventStream):
         return log_inst.EventStream(list(map(func, log)), attributes=log.attributes, classifiers=log.classifiers,
-                                    omni_present=log.omni_present, extensions=log.extensions)
+                                    omni_present=log.omni_present, extensions=log.extensions, properties=log.properties)
     else:
         warnings.warn('input log object not of appropriate type, map() not applied')
         return log
@@ -80,11 +80,11 @@ def map_(func, log):
 def sort_(func, log, reverse=False):
     if isinstance(log, log_inst.EventLog):
         return log_inst.EventLog(sorted(log, key=func, reverse=reverse), attributes=log.attributes,
-                                 classifiers=log.classifiers, omni_present=log.omni_present, extensions=log.extensions)
+                                 classifiers=log.classifiers, omni_present=log.omni_present, extensions=log.extensions, properties=log.properties)
     elif isinstance(log, log_inst.EventStream):
         return log_inst.EventStream(sorted(log, key=func, reverse=reverse), attributes=log.attributes,
                                     classifiers=log.classifiers,
-                                    omni_present=log.omni_present, extensions=log.extensions)
+                                    omni_present=log.omni_present, extensions=log.extensions, properties=log.properties)
     else:
         warnings.warn('input log object not of appropriate type, map() not applied')
         return log
