@@ -36,7 +36,7 @@ def sample_stream(event_log, no_events=100):
     newLog
         Filtered log
     """
-    new_log = EventStream(attributes=event_log.attributes, extensions=event_log.extensions, globals=event_log._omni,
+    new_log = EventStream(attributes=event_log.attributes, extensions=event_log.extensions, globals=event_log.omni_present,
                           classifiers=event_log.classifiers)
     new_log._list = random.sample(event_log, min(no_events, len(event_log)))
     return new_log
@@ -58,7 +58,7 @@ def sample_log(log, no_traces=100):
     newLog
         Filtered log
     """
-    new_log = EventLog(attributes=log.attributes, extensions=log.extensions, globals=log._omni,
+    new_log = EventLog(attributes=log.attributes, extensions=log.extensions, globals=log.omni_present,
                        classifiers=log.classifiers, properties=log.properties)
     new_log._list = random.sample(log, min(no_traces, len(log)))
     return new_log
