@@ -14,9 +14,13 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
+import warnings
+
+warnings.warn('please use the pm4py.objects.petri_net package instead.')
+
 import pkgutil
 
-from pm4py.objects.petri import common, incidence_matrix, petrinet, \
+from pm4py.objects.petri import common, incidence_matrix, obj, \
     reachability_graph, semantics, synchronous_product, utils, check_soundness, networkx_graph, align_utils, \
     explore_path, performance_map, embed_stochastic_map, reduction
 
