@@ -43,8 +43,9 @@ class Parameters(Enum):
     SORT_ASCENDING = "sort_ascending"
     MAX_RET_CASES = "max_ret_cases"
     BUSINESS_HOURS = "business_hours"
-    WORKTIMING = "worktiming"
+    WORKTIMING  = "worktiming"
     WEEKENDS = "weekends"
+    WORKCALENDAR = "workcalendar"
 
     INDEXED_LOG = "indexed_log"
 
@@ -131,6 +132,7 @@ def get_cases_description(log: EventLog,  parameters: Optional[Dict[Union[str, P
     business_hours = exec_utils.get_param_value(Parameters.BUSINESS_HOURS, parameters, False)
     worktiming = exec_utils.get_param_value(Parameters.WORKTIMING, parameters, [7, 17])
     weekends = exec_utils.get_param_value(Parameters.WEEKENDS, parameters, [6, 7])
+    workcalendar = exec_utils.get_param_value(Parameters.WORKCALENDAR, parameters, constants.DEFAULT_BUSINESS_HOURS_WORKCALENDAR)
 
     statistics_list = []
 
@@ -141,7 +143,7 @@ def get_cases_description(log: EventLog,  parameters: Optional[Dict[Union[str, P
             et = trace[-1][timestamp_key]
             if business_hours:
                 bh = BusinessHours(st.replace(tzinfo=None), et.replace(tzinfo=None), worktiming=worktiming,
-                                   weekends=weekends)
+                                   weekends=weekends, workcalendar=workcalendar)
                 diff = bh.getseconds()
             else:
                 diff = et.timestamp() - st.timestamp()
