@@ -14,4 +14,8 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.statistics.traces.log import case_statistics, case_arrival
+import warnings
+
+warnings.warn("pm4py.statistics.traces.log is deprecated. Please use pm4py.statistics.traces.generic.log instead!")
+
+from pm4py.statistics.traces.generic.log import *
